package Genome::Vocabulary;

use warnings;
use strict;
use Genome;

class Genome::Vocabulary {
    is => 'UR::Vocabulary',
};

1;

=pod 

=head1 NAME

Genome::Vocabulary

=head1 DESCRIPTION

This module is used by the Genome namespace to identify domain-specific terminology in the software reflection system.

=cut

